import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/customer_screen.dart';

class DetailFlightScreen extends StatefulWidget {
  const DetailFlightScreen({Key? key}) : super(key: key);

  @override
  State<DetailFlightScreen> createState() => _DetailFlightScreenState();
}

class _DetailFlightScreenState extends State<DetailFlightScreen> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            Expanded(
              child: ListView(
                physics: const BouncingScrollPhysics(),
                children: [
                  const SizedBox(height: 16.0),
                  Align(
                    alignment: Alignment.center,
                    child: Utils.getText(
                      "Hồ Chí Minh - Hà Nội",
                      18,
                      FontWeight.w500,
                      Colors.black,
                    ),
                  ),
                  const SizedBox(height: 16.0),
                  const SizedBox(height: 16.0),
                  _buildDetailView("22:10", "00:10", "1,450,000đ"),
                  const SizedBox(height: 16.0),
                  _buildDetailView("10:10", "12:10", "1,000,000đ"),
                ],
              ),
            ),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              Colors.deepPurple,
              null,
              () {
                _trackEvent();
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }

  Widget _buildDetailView(
    String timeSGN,
    String timeHAN,
    String money,
  ) {
    return Container(
      padding: const EdgeInsets.fromLTRB(16.0, 16.0, 16.0, 16.0),
      decoration: BoxDecoration(
        border: Border.all(
          width: 1.0,
          color: Colors.grey,
        ),
        borderRadius: const BorderRadius.all(Radius.circular(0)),
      ),
      child: Row(
        children: [
          Column(
            children: [
              Utils.getText(
                "SGN",
                16.0,
                FontWeight.w500,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              Utils.getText(
                timeSGN,
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Column(
            children: [
              Utils.getText(
                "2 giờ 10 phút",
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              const SizedBox(height: 16.0),
              Utils.getText(
                "Bay thẳng",
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Column(
            children: [
              Utils.getText(
                "HAN",
                16.0,
                FontWeight.w500,
                Colors.black,
              ),
              const SizedBox(height: 16.0),
              Utils.getText(
                timeHAN,
                14.0,
                FontWeight.w400,
                Colors.black,
              ),
            ],
          ),
          const SizedBox(width: 16.0),
          Container(
            height: 80.0,
            color: Colors.grey,
            width: 1.0,
          ),
          const SizedBox(width: 16.0),
          Expanded(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Utils.getText(
                  "Giá từ",
                  14.0,
                  FontWeight.w400,
                  Colors.black,
                ),
                const SizedBox(height: 16.0),
                Utils.getText(
                  money,
                  14.0,
                  FontWeight.w400,
                  Colors.black,
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }

  void _trackEvent() {
    Analytics.trackEvent(
      workSpaceId,
      {
        "deviceId": deviceId,
      },
      "add_to_cart",
      DateTime.now().millisecondsSinceEpoch,
      {
        "platform": "APP",
        "departure_location": "SGN HAN",
        "departure_time": "22:10 00:10",
        "departure_money": "1,450,000d",
        "arrival_location": "HAN SGN",
        "arrival_time": "10:10 12:10",
        "arrival_money": "1,000,000d",
        "flight_time": "22:10 00:10",
        "flight_date": "CN (16/01/2022)",
        "trip_route": "SGN - HN",
        "trip_type": "roundTrip",
        "flight_from": "HAN",
        "flight_to": "SGN",
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        Get.to(() => const CustomerScreen());
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
      },
    );
  }
}
